@@ -1,5 +1,26 @@
 <?php
 
+/*
+ * This file is part of pgFouine.
+ * 
+ * pgFouine - a PostgreSQL log analyzer
+ * Copyright (c) 2005-2006 Guillaume Smet
+ *
+ * pgFouine is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ *
+ * pgFouine is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with pgFouine; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
+ */
+
 class QueriesByTypeReport extends Report {
 	function QueriesByTypeReport(& $reportAggregator) {
 		$this->Report($reportAggregator, 'Queries by type', array('GlobalCountersListener'));
@@ -9,7 +30,7 @@ class QueriesByTypeReport extends Report {
 		$listener =& $this->reportAggregator->getListener('GlobalCountersListener');
 		$text = '';
 		
-		$queriesCount = $listener->getQueryCount();
+		$queriesCount = $listener->getIdentifiedQueryCount();
 		$selectCount = $listener->getSelectCount();
 		$insertCount = $listener->getInsertCount();
 		$updateCount = $listener->getUpdateCount();
@@ -39,7 +60,7 @@ class QueriesByTypeReport extends Report {
 	function getHtml() {
 		$listener =& $this->reportAggregator->getListener('GlobalCountersListener');
 		
-		$queriesCount = $listener->getQueryCount();
+		$queriesCount = $listener->getIdentifiedQueryCount();
 		
 		$typeCount = array();
 		if($listener->getSelectCount()) {
